@@ -382,11 +382,11 @@ draw_fiberlamp(ModeInfo * mi)
 		n->z = p->z + LEN(i-1) * se * sp;
 	  }
 
-	  fs->draw[i-1].x = cx + MI_WIDTH(mi)/2*n->x;
+	  fs->draw[i-1].x = (short) (cx + MI_WIDTH(mi)/2*n->x);
 #if defined PLAN || defined CHECKCOLORWHEEL /* Plan */
-	  fs->draw[i-1].y = cy + MI_WIDTH(mi)/2*n->z;
+	  fs->draw[i-1].y = (short) (cy + MI_WIDTH(mi)/2*n->z);
 #else /* Elevation */
-	  fs->draw[i-1].y = cy + MI_WIDTH(mi)/2*n->y;
+	  fs->draw[i-1].y = (short) (cy + MI_WIDTH(mi)/2*n->y);
 #endif
 	}
 	MI_IS_DRAWN(mi) = True;
@@ -406,7 +406,8 @@ draw_fiberlamp(ModeInfo * mi)
 	  double y = fs->node[1].z + 0.02;
 	  double angle = atan2(y, x) + fl->psi;
 	  int tipcolor = MI_PIXEL(mi,
-		(int)(MI_NPIXELS(mi)*angle/(2*M_PI)) % MI_NPIXELS(mi));
+		(int)(MI_NPIXELS(mi)*angle/(2*M_PI) + MI_NPIXELS(mi)) %
+		MI_NPIXELS(mi));
 	  int fibercolor;
 	  int tiplen;
 
