@@ -105,7 +105,7 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-  {(caddr_t *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
+  {(void *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
 };
 
 static OptionStruct desc[] =
@@ -169,8 +169,8 @@ ModStruct   maze_description =
 #define END_SQUARE	0x1
 
 typedef struct {
-	unsigned char x;
-	unsigned char y;
+	unsigned int x;
+	unsigned int y;
 	char        dir;
 } paths;
 
@@ -183,7 +183,7 @@ typedef struct {
 	int         xs, ys, logo_size_x, logo_size_y;
 	int         solving, current_path, stage;
 	int         cycles;
-	unsigned short *maze;
+	unsigned int *maze;
 	paths      *move_list;
 	paths      *save_path, *path;
 	GC          grayGC;
@@ -310,7 +310,7 @@ free_path(mazestruct * mp)
 {
 	if (mp->maze) {
 		free(mp->maze);
-		mp->maze = (unsigned short *) NULL;
+		mp->maze = (unsigned int *) NULL;
 	}
 	if (mp->move_list) {
 		free(mp->move_list);
@@ -389,8 +389,8 @@ set_maze_sizes(ModeInfo * mi)
 	mp->yb = (mp->height - mp->nrows * mp->ys) / 2;
 	mp->maze_size = mp->ncols * mp->nrows;
 	if (!mp->maze)
-		if ((mp->maze = (unsigned short *) calloc(mp->maze_size,
-				 sizeof (unsigned short))) == NULL) {
+		if ((mp->maze = (unsigned int *) calloc(mp->maze_size,
+				 sizeof (unsigned int))) == NULL) {
 			free_maze(display, mp);
 			return False;
 		}
@@ -996,7 +996,7 @@ draw_maze(ModeInfo * mi)
 	if (mp->solving) {
 		if (trackmouse)
 			mouse_maze(mi);
-		else 
+		else
 			solve_maze(mi);
 		return;
 	}
