@@ -808,7 +808,7 @@ init_nose(ModeInfo * mi)
 			return;
 		}
 	np->words = getWords(MI_SCREEN(mi), MI_NUM_SCREENS(mi));
-	if (np->text_fg_gc == NULL && mode_font != None) {
+	if (np->text_fg_gc == None && mode_font != None) {
 #ifndef USE_MB
 		gcv.font = mode_font->fid;
 		XSetFont(display, gc, mode_font->fid);
