@@ -735,10 +735,8 @@ draw_without_bitmaps(ModeInfo * mi, polyominoesstruct *sp) {
     }
   }
   XDrawSegments(display, window, gc, sp->lines, nr_lines);
-
   XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
   XDrawRectangle(display, window, gc, sp->x_margin, sp->y_margin, sp->box*sp->width, sp->box*sp->height);
-
   XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 
   nr_lines = 0;
@@ -2141,14 +2139,12 @@ init_polyominoes(ModeInfo * mi) {
     sp->box = box1;
   else
     sp->box = box2;
-
   if (sp->box >= 12) {
     sp->box = (sp->box/12)*12;
     create_bitmaps(mi,sp);
     if (!sp->use_bitmaps)
       free_bitmaps(sp);
-   }
-   else
+   } else
      sp->use_bitmaps = 0;
 
   if (!sp->use_bitmaps) {
