@@ -115,9 +115,9 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & shade, (char *) "shade", (char *) "Shade", (char *) DEF_SHADE, t_Bool},
-	{(caddr_t *) & border, (char *) "border", (char *) "Border", (char *) DEF_BORDER, t_Bool},
-	{(caddr_t *) & stipple, (char *) "stipple", (char *) "Stipple", (char *) DEF_STIPPLE, t_Bool}
+	{(void *) & shade, (char *) "shade", (char *) "Shade", (char *) DEF_SHADE, t_Bool},
+	{(void *) & border, (char *) "border", (char *) "Border", (char *) DEF_BORDER, t_Bool},
+	{(void *) & stipple, (char *) "stipple", (char *) "Stipple", (char *) DEF_STIPPLE, t_Bool}
 };
 static OptionStruct desc[] =
 {
