@@ -709,17 +709,17 @@ losira (Display *dpy, Window window, GC gc, int width, int height, int delay,
 #define ERASEMODE "losira"
   XGCValues gcv;
   XWindowAttributes wa;
-  GC white_gc; 
+  GC white_gc;
   XArc arc[2][8];
   double xx[8], yy[8], dx[8], dy[8];
   int i;
   int max = width/2;
   int max_off = MAX(1, max / 12);
-  int actual_delay = 0.55 * delay / max;
+  int actual_delay = (int) (0.55 * delay / max);
 
 #include "erase_init.h"
 
-  XGetWindowAttributes(dpy, window, &wa);
+  (void) XGetWindowAttributes(dpy, window, &wa);
   gcv.foreground = XWhitePixelOfScreen(wa.screen);
   white_gc = XCreateGC(dpy, window, GCForeground, &gcv);
 
@@ -768,9 +768,9 @@ losira (Display *dpy, Window window, GC gc, int width, int height, int delay,
   XSync(dpy, False);
 
   /* Collapse vertically */
- 
+
   max = height/2;
-  actual_delay = 0.30 * delay / max;
+  actual_delay = (int) (0.30 * delay / max);
   for ( i=0; i<max; i++ )
      {
 	int x = (width-max_off)/2;
@@ -813,13 +813,13 @@ losira (Display *dpy, Window window, GC gc, int width, int height, int delay,
   arc[0][5].angle1 = arc[1][5].angle1 = 225*64; arc[0][5].angle2 = arc[1][5].angle2 =  45*64;
   arc[0][6].angle1 = arc[1][6].angle1 = 270*64; arc[0][6].angle2 = arc[1][6].angle2 =  45*64;
   arc[0][7].angle1 = arc[1][7].angle1 = 315*64; arc[0][7].angle2 = arc[1][7].angle2 =  45*64;
-  
+
   for( i = 0; i < 8; i++ ) {
     dx[i] =  cos((i*45 + 22.5)/360 * 2*M_PI);
     dy[i] = -sin((i*45 + 22.5)/360 * 2*M_PI);
   }
 
-  gcv.line_width = 3;  
+  gcv.line_width = 3;
   XChangeGC(dpy, gc, GCLineWidth, &gcv);
 
   XClearWindow (dpy, window);
@@ -838,7 +838,7 @@ losira (Display *dpy, Window window, GC gc, int width, int height, int delay,
 
 
   /* Fan out */
-  actual_delay = 0.15 * delay / max_off;
+  actual_delay = (int) (0.15 * delay / max_off);
   for ( i=0; i<max_off; i++ )
      {
 	int j;
@@ -846,8 +846,8 @@ losira (Display *dpy, Window window, GC gc, int width, int height, int delay,
             {
               xx[j] += 2*dx[j];
               yy[j] += 2*dy[j];
-              arc[(i+1)%2][j].x = xx[j];
-              arc[(i+1)%2][j].y = yy[j];
+              arc[(i+1)%2][j].x = (short) xx[j];
+              arc[(i+1)%2][j].y = (short) yy[j];
             }
 
           XFillRectangle (dpy, window, gc,
@@ -860,7 +860,7 @@ losira (Display *dpy, Window window, GC gc, int width, int height, int delay,
 #undef LOOPVAR
      }
   XFreeGC(dpy, white_gc);
-  gcv.line_width = 1;  
+  gcv.line_width = 1;
   XChangeGC(dpy, gc, GCLineWidth, &gcv);
 }
 
