@@ -304,75 +304,73 @@ PAM_conv(int num_msg,
 	reply = (struct pam_response *) malloc(sizeof (struct pam_response) *
 					       num_msg);
 
+// reply[] members is not initialized!
+// As a result - abort trap when PAM tries to free reply structure
+// after PAM_ERROR_MSG processing.
+
+// So I just initialize reply here with default values and drop
+// initialization from code below (if code matches).
+
+	reply[replies].resp_retcode = PAM_SUCCESS; // be optimistic
+	reply[replies].resp = NULL;
+
 	if (!reply)
 		return PAM_CONV_ERR;
 
 	for (replies = 0; replies < num_msg; replies++) {
+#ifdef DEBUG
+		(void) printf( "PAM_conv: message of style (%d) received\n", msg[replies]->msg_style );
+		(void) printf( " + Message is: (%s)\n", msg[replies]->msg );
+#endif
 		switch (msg[replies]->msg_style) {
 			case PAM_PROMPT_ECHO_ON:
-  			        PAM_putText( msg[replies], &reply[replies], True );
 #ifdef DEBUG
-			        (void) printf( "Back From PAM_putText: PAM_PROMPT_ECHO_ON\n" );
-			        (void) printf( "Response is: (%s)\n, Return Code is: (%d)\n",
-					 reply[replies].resp, reply[replies].resp_retcode );
+				(void) printf( " + Message style: PAM_PROMPT_ECHO_ON\n" );
 #endif
+				PAM_putText( msg[replies], &reply[replies], True );
 				/* PAM frees resp */
 				break;
 			case PAM_PROMPT_ECHO_OFF:
-			  if( strstr( msg[replies]->msg, "Password" ) == NULL )
-			  {
-			    PAM_putText( msg[replies], &reply[replies], False );
-			  }
-			  else
-			  {
-			    reply[replies].resp_retcode = PAM_SUCCESS;
-			    reply[replies].resp = COPY_STRING(PAM_password);
-			  }
 #ifdef DEBUG
-			        (void) printf( "Back From PAM_putText: PAM_PROMPT_ECHO_OFF\n" );
-			        (void) printf( "Response is: (%s)\n, Return Code is: (%d)\n",
-					 reply[replies].resp, reply[replies].resp_retcode );
+				(void) printf( " + Message style: PAM_PROMPT_ECHO_OFF\n" );
 #endif
+				if( strstr( msg[replies]->msg, "Password" ) == NULL ) {
+					PAM_putText( msg[replies], &reply[replies], False );
+				} else {
+					reply[replies].resp = COPY_STRING(PAM_password);
+				}
 				/* PAM frees resp */
 				break;
 			case PAM_TEXT_INFO:
-			  if( strstr( msg[replies]->msg, "Password" ) == NULL )
-			  {
-			    PAM_putText( msg[replies], &reply[replies], False );
-			  }
-			  else
-			  {
-			    reply[replies].resp_retcode = PAM_SUCCESS;
-			    reply[replies].resp = NULL;
-			  }
 #ifdef DEBUG
-			        (void) printf( "Back From PAM_putText: PAM_PROMPT_ECHO_ON\n" );
-			        (void) printf( "Response is: (%s)\n, Return Code is: (%d)\n",
-					 reply[replies].resp, reply[replies].resp_retcode );
+				(void) printf( " + Message style: PAM_TEXT_INFO\n" );
 #endif
+				if( strstr( msg[replies]->msg, "Password" ) == NULL ) {
+					PAM_putText( msg[replies], &reply[replies], False );
+				}
 				/* PAM frees resp */
 				break;
 			case PAM_ERROR_MSG:
-			  if( strstr( msg[replies]->msg, "Password" ) == NULL )
-			  {
-			    PAM_putText( msg[replies], &reply[replies], False );
-			  }
-			  else
-			  {
-			    reply[replies].resp_retcode = PAM_SUCCESS;
-			    reply[replies].resp = NULL;
-			  }
 #ifdef DEBUG
-			        (void) printf( "Back From PAM_putText: PAM_PROMPT_ECHO_ON\n" );
-			        (void) printf( "Response is: (%s)\n, Return Code is: (%d)\n",
-					 reply[replies].resp, reply[replies].resp_retcode );
+				(void) printf( " + Message style: PAM_ERROR_MSG\n" );
 #endif
+				if( strstr( msg[replies]->msg, "Password" ) == NULL ) {
+					PAM_putText( msg[replies], &reply[replies], False );
+				}
+				/* PAM frees resp */
 				break;
 			default:
 				/* Must be an error of some sort... */
+#ifdef DEBUG
+				(void) printf( " + Message style: unknown\n" );
+#endif
 				free(reply);
 				return PAM_CONV_ERR;
 		}
+#ifdef DEBUG
+		(void) printf( " + Response is: (%s). Return Code is: (%d)\n",
+			reply[replies].resp, reply[replies].resp_retcode );
+#endif
 	}
 	*resp = reply;
 	return PAM_SUCCESS;
@@ -1191,6 +1189,9 @@ checkPasswd(char *buffer)
 #ifdef BAD_PAM
 	ruid = getuid();  /* the real user we are running as */
 	(void) seteuid(0); /* temporarily go to root so that pam can get shadow password */
+#endif
+#ifdef DEBUG
+	(void) printf("PAM: Before: UID (%d), EUID (%d)\n", getuid(), geteuid());
 #endif
 	PAM_password = buffer;
 	pam_error = pam_start("xlock", user, &PAM_conversation, &pamh);
@@ -1203,10 +1204,12 @@ checkPasswd(char *buffer)
 	}
 
 	pam_error = pam_authenticate(pamh, 0);
+#ifdef DEBUG
+	(void) printf("PAM: pam_authenticate returns code (%d)\n", pam_error);
+#endif
 	if (pam_error != PAM_SUCCESS) {
                 if (!allowroot) {
-                        pam_end(pamh, 0);
-                        return False;
+					PAM_BAIL;
                 }
 
 		/* Try as root; bail if no success there either */
@@ -1218,6 +1221,9 @@ checkPasswd(char *buffer)
 #ifdef BAD_PAM
 	(void) seteuid(ruid); /* back to user's privileges */
 #endif
+#ifdef DEBUG
+	(void) printf("PAM: After: UID (%d), EUID (%d)\n", getuid(), geteuid());
+#endif
 
 /* Seems to cause problems on several systems including GenToo if defined */
 /* https://bugs.gentoo.org/show_bug.cgi?id=96212 */
